@@ -6,7 +6,6 @@ from cmd import Cmd
 
 
 class Repl(Cmd):
-
     def __init__(self, cli_function, prompt="", help=None):
         super().__init__()
         self.cli_function = cli_function
@@ -27,25 +26,23 @@ class Repl(Cmd):
         self._update_prompt()
 
     def do_EOF(self, inp):
-        print('^D')
+        print("^D")
         return True
 
     def emptyline(self):
         self._update_prompt()
 
     def default(self, inp):
-        if inp.startswith('.') and len(inp) > 1:
+        if inp.startswith(".") and len(inp) > 1:
             os.system(inp[1:])
             self._update_prompt()
             return False
         try:
             self.cli_function(shlex.split(inp))
-        except AssertionError as ae:
-            sys.stderr.write(f'{ae}\n')
         except KeyboardInterrupt:
-            print('^C')
+            print("^C")
         except EOFError:
-            print('^D')
+            print("^D")
             return True
         except:
             traceback.print_exc()
@@ -59,17 +56,15 @@ def reploncli(cli_function, repl_mode=None, help=None, prompt=""):
     if repl_mode is True:
         repl = Repl(cli_function, prompt, help)
         nothing_worse_than_keyboardinterrupt = True
-        while(nothing_worse_than_keyboardinterrupt):
+        while nothing_worse_than_keyboardinterrupt:
             nothing_worse_than_keyboardinterrupt = False
             try:
                 repl.cmdloop()
             except KeyboardInterrupt:
-                sys.stderr.write('^C\n')
+                sys.stderr.write("^C\n")
                 nothing_worse_than_keyboardinterrupt = True
     else:
         try:
             cli_function()
-        except AssertionError as ae:
-            sys.stderr.write(f'{ae}\n')
         except (KeyboardInterrupt, EOFError):
             print()
